AssociateVPCWithHostedZoneRequest class

A complex type that contains information about the request to associate a VPC with a private hosted zone.

Constructors

AssociateVPCWithHostedZoneRequest({required String hostedZoneId, required VPC vpc, String? comment})

Properties

comment → String?
Optional: A comment about the association request.
final
hashCode → int
The hash code for this object.
no setterinherited
hostedZoneId → String
The ID of the private hosted zone that you want to associate an Amazon VPC with.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpc → VPC
A complex type that contains information about the VPC that you want to associate with a private hosted zone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited