Change class

The information for each resource record set that you want to change.

Constructors

Change({required ChangeAction action, required ResourceRecordSet resourceRecordSet})

Properties

action → ChangeAction
The action to perform:
final
hashCode → int
The hash code for this object.
no setterinherited
resourceRecordSet → ResourceRecordSet
Information about the resource record set to create, delete, or update.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited