ChangeBatch class

The information for a change request.

Constructors

ChangeBatch({required List<Change> changes, String? comment})

Properties

changes → List<Change>
Information about the changes to make to the record sets.
final
comment → String?
Optional: Any comments you want to include about a change batch request.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited