ChangeInfo class

A complex type that describes change information about changes made to your hosted zone.

Constructors

ChangeInfo({required String id, required ChangeStatus status, required DateTime submittedAt, String? comment})
ChangeInfo.fromXml(XmlElement elem)
factory

Properties

comment → String?
A complex type that describes change information about changes made to your hosted zone.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID of the request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ChangeStatus
The current state of the request. PENDING indicates that this request has not yet been applied to all Amazon Route 53 DNS servers.
final
submittedAt → DateTime
The date and time that the change request was submitted in ISO 8601 format and Coordinated Universal Time (UTC). For example, the value 2017-03-27T17:48:16.751Z represents March 27, 2017 at 17:48:16.751 UTC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited