ChangeResourceRecordSetsRequest class

A complex type that contains change information for the resource record set.

Constructors

ChangeResourceRecordSetsRequest({required ChangeBatch changeBatch, required String hostedZoneId})

Properties

changeBatch → ChangeBatch
A complex type that contains an optional comment and the Changes element.
final
hashCode → int
The hash code for this object.
no setterinherited
hostedZoneId → String
The ID of the hosted zone that contains the resource record sets that you want to change.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited