CreateHealthCheckResponse class

A complex type containing the response information for the new health check.

Constructors

CreateHealthCheckResponse({required HealthCheck healthCheck, required String location})

Properties

hashCode → int
The hash code for this object.
no setterinherited
healthCheck → HealthCheck
A complex type that contains identifying information about the health check.
final
location → String
The unique URL representing the new health check.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited