CreateHostedZoneResponse class

A complex type containing the response information for the hosted zone.

Constructors

CreateHostedZoneResponse({required ChangeInfo changeInfo, required DelegationSet delegationSet, required HostedZone hostedZone, required String location, VPC? vpc})

Properties

changeInfo → ChangeInfo
A complex type that contains information about the CreateHostedZone request.
final
delegationSet → DelegationSet
A complex type that describes the name servers for this hosted zone.
final
hashCode → int
The hash code for this object.
no setterinherited
hostedZone → HostedZone
A complex type that contains general information about the hosted zone.
final
location → String
The unique URL representing the new hosted zone.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpc → VPC?
A complex type that contains information about an Amazon VPC that you associated with this hosted zone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited