CreateKeySigningKeyResponse class

Constructors

CreateKeySigningKeyResponse({required ChangeInfo changeInfo, required KeySigningKey keySigningKey, required String location})

Properties

changeInfo → ChangeInfo
final
hashCode → int
The hash code for this object.
no setterinherited
keySigningKey → KeySigningKey
The key signing key (KSK) that the request creates.
final
location → String
The unique URL representing the new key signing key (KSK).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited