CreateQueryLoggingConfigRequest class

Constructors

CreateQueryLoggingConfigRequest({required String cloudWatchLogsLogGroupArn, required String hostedZoneId})

Properties

cloudWatchLogsLogGroupArn → String
The Amazon Resource Name (ARN) for the log group that you want to Amazon Route 53 to send query logs to. This is the format of the ARN:
final
hashCode → int
The hash code for this object.
no setterinherited
hostedZoneId → String
The ID of the hosted zone that you want to log queries for. You can log queries only for public hosted zones.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited