CreateReusableDelegationSetRequest class

Constructors

CreateReusableDelegationSetRequest({required String callerReference, String? hostedZoneId})

Properties

callerReference → String
A unique string that identifies the request, and that allows you to retry failed CreateReusableDelegationSet requests without the risk of executing the operation twice. You must use a unique CallerReference string every time you submit a CreateReusableDelegationSet request. CallerReference can be any unique string, for example a date/time stamp.
final
hashCode → int
The hash code for this object.
no setterinherited
hostedZoneId → String?
If you want to mark the delegation set for an existing hosted zone as reusable, the ID for that hosted zone.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited