CreateTrafficPolicyRequest class

A complex type that contains information about the traffic policy that you want to create.

Constructors

CreateTrafficPolicyRequest({required String document, required String name, String? comment})

Properties

comment → String?
(Optional) Any comments that you want to include about the traffic policy.
final
document → String
The definition of this traffic policy in JSON format. For more information, see Traffic Policy Document Format.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the traffic policy.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited