CreateTrafficPolicyResponse class

A complex type that contains the response information for the CreateTrafficPolicy request.

Constructors

CreateTrafficPolicyResponse({required String location, required TrafficPolicy trafficPolicy})

Properties

hashCode → int
The hash code for this object.
no setterinherited
location → String
A unique URL that represents a new traffic policy.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trafficPolicy → TrafficPolicy
A complex type that contains settings for the new traffic policy.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited