DelegationSet class

A complex type that lists the name servers in a delegation set, as well as the CallerReference and the ID for the delegation set.

Constructors

DelegationSet({required List<String> nameServers, String? callerReference, String? id})
DelegationSet.fromXml(XmlElement elem)
factory

Properties

callerReference → String?
The value that you specified for CallerReference when you created the reusable delegation set.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID that Amazon Route 53 assigns to a reusable delegation set.
final
nameServers → List<String>
A complex type that contains a list of the authoritative name servers for a hosted zone or for a reusable delegation set.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited