GetAccountLimitResponse class

A complex type that contains the requested limit.

Constructors

GetAccountLimitResponse({required int count, required AccountLimit limit})
GetAccountLimitResponse.fromXml(XmlElement elem)
factory

Properties

count → int
The current number of entities that you have created of the specified type. For example, if you specified MAX_HEALTH_CHECKS_BY_OWNER for the value of Type in the request, the value of Count is the current number of health checks that you have created using the current account.
final
hashCode → int
The hash code for this object.
no setterinherited
limit → AccountLimit
The current setting for the specified limit. For example, if you specified MAX_HEALTH_CHECKS_BY_OWNER for the value of Type in the request, the value of Limit is the maximum number of health checks that you can create using the current account.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited