GetCheckerIpRangesResponse class

A complex type that contains the CheckerIpRanges element.

Constructors

GetCheckerIpRangesResponse({required List<String> checkerIpRanges})
GetCheckerIpRangesResponse.fromXml(XmlElement elem)
factory

Properties

checkerIpRanges → List<String>
A complex type that contains sorted list of IP ranges in CIDR format for Amazon Route 53 health checkers.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited