GetDNSSECResponse class

Constructors

GetDNSSECResponse({required List<KeySigningKey> keySigningKeys, required DNSSECStatus status})
GetDNSSECResponse.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
keySigningKeys → List<KeySigningKey>
The key signing keys (KSKs) in your account.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DNSSECStatus
A string repesenting the status of DNSSEC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited