GetGeoLocationResponse class

A complex type that contains the response information for the specified geolocation code.

Constructors

GetGeoLocationResponse({required GeoLocationDetails geoLocationDetails})
GetGeoLocationResponse.fromXml(XmlElement elem)
factory

Properties

geoLocationDetails → GeoLocationDetails
A complex type that contains the codes and full continent, country, and subdivision names for the specified geolocation code.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited