GetHealthCheckLastFailureReasonResponse class

A complex type that contains the response to a GetHealthCheckLastFailureReason request.

Constructors

GetHealthCheckLastFailureReasonResponse({required List<HealthCheckObservation> healthCheckObservations})
GetHealthCheckLastFailureReasonResponse.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
healthCheckObservations → List<HealthCheckObservation>
A list that contains one Observation element for each Amazon Route 53 health checker that is reporting a last failure reason.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited