GetHostedZoneCountResponse class

A complex type that contains the response to a GetHostedZoneCount request.

Constructors

GetHostedZoneCountResponse({required int hostedZoneCount})
GetHostedZoneCountResponse.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostedZoneCount → int
The total number of public and private hosted zones that are associated with the current AWS account.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited