limit property
The current setting for the specified limit. For example, if you specified
MAX_RRSETS_BY_ZONE for the value of Type in the
request, the value of Limit is the maximum number of records
that you can create in the specified hosted zone.
Implementation
final HostedZoneLimit limit;