GetQueryLoggingConfigResponse class

Constructors

GetQueryLoggingConfigResponse({required QueryLoggingConfig queryLoggingConfig})
GetQueryLoggingConfigResponse.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
queryLoggingConfig → QueryLoggingConfig
A complex type that contains information about the query logging configuration that you specified in a GetQueryLoggingConfig request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited