GetReusableDelegationSetLimitResponse class

A complex type that contains the requested limit.

Constructors

GetReusableDelegationSetLimitResponse({required int count, required ReusableDelegationSetLimit limit})
GetReusableDelegationSetLimitResponse.fromXml(XmlElement elem)
factory

Properties

count → int
The current number of hosted zones that you can associate with the specified reusable delegation set.
final
hashCode → int
The hash code for this object.
no setterinherited
limit → ReusableDelegationSetLimit
The current setting for the limit on hosted zones that you can associate with the specified reusable delegation set.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited