HealthCheck class

A complex type that contains information about one health check that is associated with the current AWS account.

Constructors

HealthCheck({required String callerReference, required HealthCheckConfig healthCheckConfig, required int healthCheckVersion, required String id, CloudWatchAlarmConfiguration? cloudWatchAlarmConfiguration, LinkedService? linkedService})
HealthCheck.fromXml(XmlElement elem)
factory

Properties

callerReference → String
A unique string that you specified when you created the health check.
final
cloudWatchAlarmConfiguration → CloudWatchAlarmConfiguration?
A complex type that contains information about the CloudWatch alarm that Amazon Route 53 is monitoring for this health check.
final
hashCode → int
The hash code for this object.
no setterinherited
healthCheckConfig → HealthCheckConfig
A complex type that contains detailed information about one health check.
final
healthCheckVersion → int
The version of the health check. You can optionally pass this value in a call to UpdateHealthCheck to prevent overwriting another change to the health check.
final
id → String
The identifier that Amazon Route 53assigned to the health check when you created it. When you add or update a resource record set, you use this value to specify which health check to use. The value can be up to 64 characters long.
final
linkedService → LinkedService?
If the health check was created by another service, the service that created the health check. When a health check is created by another service, you can't edit or delete it using Amazon Route 53.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited