HealthCheckConfig class

A complex type that contains information about the health check.

Constructors

HealthCheckConfig({required HealthCheckType type, AlarmIdentifier? alarmIdentifier, List<String>? childHealthChecks, bool? disabled, bool? enableSNI, int? failureThreshold, String? fullyQualifiedDomainName, int? healthThreshold, String? iPAddress, InsufficientDataHealthStatus? insufficientDataHealthStatus, bool? inverted, bool? measureLatency, int? port, List<HealthCheckRegion>? regions, int? requestInterval, String? resourcePath, String? searchString})
HealthCheckConfig.fromXml(XmlElement elem)
factory

Properties

alarmIdentifier → AlarmIdentifier?
A complex type that identifies the CloudWatch alarm that you want Amazon Route 53 health checkers to use to determine whether the specified health check is healthy.
final
childHealthChecks → List<String>?
(CALCULATED Health Checks Only) A complex type that contains one ChildHealthCheck element for each health check that you want to associate with a CALCULATED health check.
final
disabled → bool?
Stops Route 53 from performing health checks. When you disable a health check, here's what happens:
final
enableSNI → bool?
Specify whether you want Amazon Route 53 to send the value of FullyQualifiedDomainName to the endpoint in the client_hello message during TLS negotiation. This allows the endpoint to respond to HTTPS health check requests with the applicable SSL/TLS certificate.
final
failureThreshold → int?
The number of consecutive health checks that an endpoint must pass or fail for Amazon Route 53 to change the current status of the endpoint from unhealthy to healthy or vice versa. For more information, see How Amazon Route 53 Determines Whether an Endpoint Is Healthy in the Amazon Route 53 Developer Guide.
final
fullyQualifiedDomainName → String?
Amazon Route 53 behavior depends on whether you specify a value for IPAddress.
final
hashCode → int
The hash code for this object.
no setterinherited
healthThreshold → int?
The number of child health checks that are associated with a CALCULATED health check that Amazon Route 53 must consider healthy for the CALCULATED health check to be considered healthy. To specify the child health checks that you want to associate with a CALCULATED health check, use the ChildHealthChecks element.
final
insufficientDataHealthStatus → InsufficientDataHealthStatus?
When CloudWatch has insufficient data about the metric to determine the alarm state, the status that you want Amazon Route 53 to assign to the health check:
final
inverted → bool?
Specify whether you want Amazon Route 53 to invert the status of a health check, for example, to consider a health check unhealthy when it otherwise would be considered healthy.
final
iPAddress → String?
The IPv4 or IPv6 IP address of the endpoint that you want Amazon Route 53 to perform health checks on. If you don't specify a value for IPAddress, Route 53 sends a DNS request to resolve the domain name that you specify in FullyQualifiedDomainName at the interval that you specify in RequestInterval. Using an IP address returned by DNS, Route 53 then checks the health of the endpoint.
final
measureLatency → bool?
Specify whether you want Amazon Route 53 to measure the latency between health checkers in multiple AWS regions and your endpoint, and to display CloudWatch latency graphs on the Health Checks page in the Route 53 console.
final
port → int?
The port on the endpoint that you want Amazon Route 53 to perform health checks on.
final
regions → List<HealthCheckRegion>?
A complex type that contains one Region element for each region from which you want Amazon Route 53 health checkers to check the specified endpoint.
final
requestInterval → int?
The number of seconds between the time that Amazon Route 53 gets a response from your endpoint and the time that it sends the next health check request. Each Route 53 health checker makes requests at this interval. If you don't specify a value for RequestInterval, the default value is 30 seconds.
final
resourcePath → String?
The path, if any, that you want Amazon Route 53 to request when performing health checks. The path can be any value for which your endpoint will return an HTTP status code of 2xx or 3xx when the endpoint is healthy, for example, the file /docs/route53-health-check.html. You can also include query string parameters, for example, /welcome.html?language=jp&login=y.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchString → String?
If the value of Type is HTTP_STR_MATCH or HTTPS_STR_MATCH, the string that you want Amazon Route 53 to search for in the response body from the specified resource. If the string appears in the response body, Route 53 considers the resource healthy.
final
type → HealthCheckType
The type of health check that you want to create, which indicates how Amazon Route 53 determines whether an endpoint is healthy. You can create the following types of health checks:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited