healthThreshold property
The number of child health checks that are associated with a
CALCULATED health check that Amazon Route 53 must consider
healthy for the CALCULATED health check to be considered
healthy. To specify the child health checks that you want to associate with
a CALCULATED health check, use the ChildHealthChecks
element.
Note the following:
- If you specify a number greater than the number of child health checks, Route 53 always considers this health check to be unhealthy.
-
If you specify
0, Route 53 always considers this health check to be healthy.
Implementation
final int? healthThreshold;