iPAddress property
The IPv4 or IPv6 IP address of the endpoint that you want Amazon Route 53 to
perform health checks on. If you don't specify a value for
IPAddress, Route 53 sends a DNS request to resolve the domain
name that you specify in FullyQualifiedDomainName at the
interval that you specify in RequestInterval. Using an IP
address returned by DNS, Route 53 then checks the health of the endpoint.
Use one of the following formats for the value of IPAddress:
-
IPv4 address: four values between 0 and 255, separated by periods
(.), for example,
192.0.2.44. -
IPv6 address: eight groups of four hexadecimal values, separated by
colons (:), for example,
2001:0db8:85a3:0000:0000:abcd:0001:2345. You can also shorten IPv6 addresses as described in RFC 5952, for example,2001:db8:85a3::abcd:1:2345.
IPAddress. This ensures that the IP address of your
instance will never change.
For more information, see FullyQualifiedDomainName.
Constraints: Route 53 can't check the health of endpoints for which the IP address is in local, private, non-routable, or multicast ranges. For more information about IP addresses for which you can't create health checks, see the following documents:
- RFC 5735, Special Use IPv4 Addresses
- RFC 6598, IANA-Reserved IPv4 Prefix for Shared Address Space
- RFC 5156, Special-Use IPv6 Addresses
Type is CALCULATED or
CLOUDWATCH_METRIC, omit IPAddress.
Implementation
final String? iPAddress;