HealthCheckObservation class

A complex type that contains the last failure reason as reported by one Amazon Route 53 health checker.

Constructors

HealthCheckObservation({String? iPAddress, HealthCheckRegion? region, StatusReport? statusReport})
HealthCheckObservation.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
iPAddress → String?
The IP address of the Amazon Route 53 health checker that provided the failure reason in StatusReport.
final
region → HealthCheckRegion?
The region of the Amazon Route 53 health checker that provided the status in StatusReport.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusReport → StatusReport?
A complex type that contains the last failure reason as reported by one Amazon Route 53 health checker and the time of the failed health check.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited