ListHostedZonesByVPCResponse class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hostedZoneSummaries
→ List<HostedZoneSummary>
-
A list that contains one
HostedZoneSummary element for each
hosted zone that the specified Amazon VPC is associated with. Each
HostedZoneSummary element contains the hosted zone name and ID,
and information about who owns the hosted zone.
final
-
maxItems
→ String
-
The value that you specified for
MaxItems in the most recent
ListHostedZonesByVPC request.
final
-
nextToken
→ String?
-
The value that you specified for
NextToken in the most recent
ListHostedZonesByVPC request.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited