ListResourceRecordSetsResponse class

A complex type that contains list information for the resource record set.

Constructors

ListResourceRecordSetsResponse({required bool isTruncated, required String maxItems, required List<ResourceRecordSet> resourceRecordSets, String? nextRecordIdentifier, String? nextRecordName, RRType? nextRecordType})
ListResourceRecordSetsResponse.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isTruncated → bool
A flag that indicates whether more resource record sets remain to be listed. If your results were truncated, you can make a follow-up pagination request by using the NextRecordName element.
final
maxItems → String
The maximum number of records you requested.
final
nextRecordIdentifier → String?
Resource record sets that have a routing policy other than simple: If results were truncated for a given DNS name and type, the value of SetIdentifier for the next resource record set that has the current DNS name and type.
final
nextRecordName → String?
If the results were truncated, the name of the next record in the list.
final
nextRecordType → RRType?
If the results were truncated, the type of the next record in the list.
final
resourceRecordSets → List<ResourceRecordSet>
Information about multiple resource record sets.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited