ListTrafficPolicyVersionsResponse class
A complex type that contains the response information for the request.
Constructors
-
ListTrafficPolicyVersionsResponse({required bool isTruncated, required String maxItems, required List<
TrafficPolicy> trafficPolicies, required String trafficPolicyVersionMarker}) - ListTrafficPolicyVersionsResponse.fromXml(XmlElement elem)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTruncated → bool
-
A flag that indicates whether there are more traffic policies to be listed.
If the response was truncated, you can get the next group of traffic
policies by submitting another
ListTrafficPolicyVersionsrequest and specifying the value ofNextMarkerin themarkerparameter.final - maxItems → String
-
The value that you specified for the
maxitemsparameter in theListTrafficPolicyVersionsrequest that produced the current response.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
trafficPolicies
→ List<
TrafficPolicy> -
A list that contains one
TrafficPolicyelement for each traffic policy version that is associated with the specified traffic policy.final - trafficPolicyVersionMarker → String
-
If
IsTruncatedistrue, the value ofTrafficPolicyVersionMarkeridentifies the first traffic policy that Amazon Route 53 will return if you submit another request. CallListTrafficPolicyVersionsagain and specify the value ofTrafficPolicyVersionMarkerin theTrafficPolicyVersionMarkerrequest parameter.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited