QueryLoggingConfig class

A complex type that contains information about a configuration for DNS query logging.

Constructors

QueryLoggingConfig({required String cloudWatchLogsLogGroupArn, required String hostedZoneId, required String id})
QueryLoggingConfig.fromXml(XmlElement elem)
factory

Properties

cloudWatchLogsLogGroupArn → String
The Amazon Resource Name (ARN) of the CloudWatch Logs log group that Amazon Route 53 is publishing logs to.
final
hashCode → int
The hash code for this object.
no setterinherited
hostedZoneId → String
The ID of the hosted zone that CloudWatch Logs is logging queries for.
final
id → String
The ID for a configuration for DNS query logging.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited