StatusReport class

A complex type that contains the status that one Amazon Route 53 health checker reports and the time of the health check.

Constructors

StatusReport({DateTime? checkedTime, String? status})
StatusReport.fromXml(XmlElement elem)
factory

Properties

checkedTime → DateTime?
The date and time that the health checker performed the health check in ISO 8601 format and Coordinated Universal Time (UTC). For example, the value 2017-03-27T17:48:16.751Z represents March 27, 2017 at 17:48:16.751 UTC.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
A description of the status of the health check endpoint as reported by one of the Amazon Route 53 health checkers.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited