UpdateHostedZoneCommentRequest class

A request to update the comment for a hosted zone.

Constructors

UpdateHostedZoneCommentRequest({required String id, String? comment})

Properties

comment → String?
The new comment for the hosted zone. If you don't specify a value for Comment, Amazon Route 53 deletes the existing value of the Comment element, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID for the hosted zone that you want to update the comment for.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited