UpdateTrafficPolicyCommentRequest class

A complex type that contains information about the traffic policy that you want to update the comment for.

Constructors

UpdateTrafficPolicyCommentRequest({required String comment, required String id, required int version})

Properties

comment → String
The new comment for the specified traffic policy and version.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The value of Id for the traffic policy that you want to update the comment for.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
The value of Version for the traffic policy that you want to update the comment for.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited