UpdateTrafficPolicyInstanceRequest class

A complex type that contains information about the resource record sets that you want to update based on a specified traffic policy instance.

Constructors

UpdateTrafficPolicyInstanceRequest({required String id, required int ttl, required String trafficPolicyId, required int trafficPolicyVersion})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID of the traffic policy instance that you want to update.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trafficPolicyId → String
The ID of the traffic policy that you want Amazon Route 53 to use to update resource record sets for the specified traffic policy instance.
final
trafficPolicyVersion → int
The version of the traffic policy that you want Amazon Route 53 to use to update resource record sets for the specified traffic policy instance.
final
ttl → int
The TTL that you want Amazon Route 53 to assign to all of the updated resource record sets.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited