VPC class

(Private hosted zones only) A complex type that contains information about an Amazon VPC.

Constructors

VPC({String? vPCId, VPCRegion? vPCRegion})
VPC.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vPCId → String?
final
vPCRegion → VPCRegion?
(Private hosted zones only) The region that an Amazon VPC was created in.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml(String elemName, {List<XmlAttribute>? attributes}) → XmlElement

Operators

operator ==(Object other) → bool
The equality operator.
inherited